@@ -1,5 +1,6 @@
 var NAVTREEINDEX14 =
 {
+"group__spa__system.html#ga282e1c96dc3c64fe48b01b93257191a3":[8,6,9,7,32],
 "group__spa__system.html#ga2dcb97fa874ae364a19ce37d7f7ed90f":[8,6,9,7,25],
 "group__spa__system.html#ga2e31883f569e32ad6dfcb52702d83014":[8,6,9,7,17],
 "group__spa__system.html#ga470bdc9dd5ec71d7f79bc893147420d0":[8,6,9,7,22],
@@ -248,6 +249,5 @@ var NAVTREEINDEX14 =
 "node_2type-info_8h.html":[8,6,6,5],
 "page_access.html":[5,2],
 "page_api.html":[6],
-"page_audio.html":[5,1],
-"page_client_impl.html":[6,1]
+"page_audio.html":[5,1]
 };
