@@ -1,5 +1,6 @@
 var NAVTREEINDEX16 =
 {
+"ringbuffer_8h.html":[8,6,8,11,0],
 "route-types_8h.html":[8,6,7,22],
 "route_8h.html":[8,6,7,23],
 "session-manager_8h.html":[8,5,4,0],
@@ -248,6 +249,5 @@ var NAVTREEINDEX16 =
 "structpw__endpoint__stream__info.html#ae5c7fb592c52111ce8bfc96faf4fb523":[8,5,4,20,0],
 "structpw__endpoint__stream__info.html#ae7e20969d89c3c94e3f073a5e433a80b":[8,5,4,20,3],
 "structpw__endpoint__stream__methods.html":[8,5,4,15],
-"structpw__endpoint__stream__methods.html#a06d4d4c207f88dd3e87dadee7401b785":[8,5,4,15,1],
-"structpw__endpoint__stream__methods.html#a795f1ab22b0899bc18142419723e369b":[8,5,4,15,4]
+"structpw__endpoint__stream__methods.html#a06d4d4c207f88dd3e87dadee7401b785":[8,5,4,15,1]
 };
