@@ -1,5 +1,6 @@
 var NAVTREEINDEX17 =
 {
+"structpw__endpoint__stream__methods.html#a795f1ab22b0899bc18142419723e369b":[8,5,4,15,4],
 "structpw__endpoint__stream__methods.html#ab73e2f70fc5a78721ebb38118af947b5":[8,5,4,15,0],
 "structpw__endpoint__stream__methods.html#ab7b9c94de60336876dac12fbd671e8cb":[8,5,4,15,3],
 "structpw__endpoint__stream__methods.html#ae9591b91164d11c342bfb44f87010932":[8,5,4,15,2],
@@ -248,6 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__port__info.html#a3c95bbed7080e2f033b133409315f31a":[8,2,12,1,4],
 "structpw__port__info.html#a5131d23e86aef3c0d1727a6aa6359e9c":[8,2,12,1,3],
 "structpw__port__info.html#a59e2afe4f65b5f74eb7a28f51fb958aa":[8,2,12,1,2],
-"structpw__port__info.html#ab8bd7cf30a25d379e02bfc66c5692c64":[8,2,12,1,0],
-"structpw__port__info.html#ae58ded9d9277c0f93862d58026faf4e2":[8,2,12,1,1]
+"structpw__port__info.html#ab8bd7cf30a25d379e02bfc66c5692c64":[8,2,12,1,0]
 };
