@@ -1,5 +1,6 @@
 var NAVTREEINDEX18 =
 {
+"structpw__port__info.html#ae58ded9d9277c0f93862d58026faf4e2":[8,2,12,1,1],
 "structpw__port__methods.html":[8,2,12,3],
 "structpw__port__methods.html#a3c19aedb668ea1a71bc12f89b106d94a":[8,2,12,3,2],
 "structpw__port__methods.html#a77b4f3e654eb54c6066faa61fa478186":[8,2,12,3,0],
@@ -248,6 +249,5 @@ var NAVTREEINDEX18 =
 "structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[8,6,7,38,1],
 "structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[8,6,7,38,0],
 "structspa__buffer.html":[8,6,1,7],
-"structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[8,6,1,7,0],
-"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[8,6,1,7,2]
+"structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[8,6,1,7,0]
 };
